Trait forge::PublicUsageTest[][src]

pub trait PublicUsageTest: Test {
    fn run<'t>(&self, ctx: &mut PublicUsageContext<'t>) -> Result<()>;
}
The testing interface which defines a test written from the perspective of the a public user of the network in a “testnet” like environment where there exists a funding source and a means of creating new accounts.

Required methods

Executes the test against the given context.

Implementors